You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [32/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySrvcID.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySrvcID.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleSrvcLeaseRenewals.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleSrvcLeaseRenewals.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -71,9 +72,9 @@ public class MultipleSrvcLeaseRenewals e
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
 	logger.log(Level.FINE, "MultipleSrvcLeaseRenewals : in setup() method.");
 
@@ -91,6 +92,7 @@ public class MultipleSrvcLeaseRenewals e
 	    srvcIDTmpls[i] = new ServiceTemplate(srvcRegs[i].getServiceID(),
                                                  null,null);
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrAdd.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrAdd.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnSrvcLeaseExpiration.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnSrvcLeaseExpiration.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -114,13 +115,13 @@ public class NotifyOnSrvcLeaseExpiration
      *  and the appropriate transition mask; along with a callback containing 
      *  the service ID.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
         ServiceID curSrvcID;
 	EventRegistration[] evntRegs;
         int regTransitions =   ServiceRegistrar.TRANSITION_MATCH_MATCH
                              | ServiceRegistrar.TRANSITION_MATCH_NOMATCH;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
 	logger.log(Level.FINE, "in setup() method.");
 
@@ -142,6 +143,7 @@ public class NotifyOnSrvcLeaseExpiration
 			      Long.MAX_VALUE);
 	    evntRegs[i] = prepareEventRegistration(er);
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/SrvcLeaseExpiration.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/SrvcLeaseExpiration.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentNewSrvcReg.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentNewSrvcReg.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -78,10 +79,11 @@ public class IdempotentNewSrvcReg extend
      *
      *  Creates the lookup service. Creates all the service items.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         ServiceItem[] srvcItems ;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentOldSrvcReg.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentOldSrvcReg.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentOldSrvcReg.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentOldSrvcReg.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -82,14 +83,15 @@ public class IdempotentOldSrvcReg extend
      *  with its corresponding service item (this is so that when the service
      *  is re-registered, it is registered with that same service ID). 
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         ServiceItem[] srvcItems ;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
 	ServiceRegistration[] srvcRegs = super.registerAll();
         for ( int i = 0; i < srvcItems.length; i++ ) {
             srvcItems[i].serviceID = srvcRegs[i].getServiceID();
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNonNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNonNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNonNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNonNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -136,7 +137,7 @@ public class NotifyOnComboAttrAddNonNull
      *  requests a handback which contains the associated service/attribute 
      *  "tuple" to be associated with the event.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -161,7 +162,7 @@ public class NotifyOnComboAttrAddNonNull
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* load and create an initialized instance (non-null fields) of each
@@ -243,6 +244,7 @@ public class NotifyOnComboAttrAddNonNull
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrAddNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -136,7 +137,7 @@ public class NotifyOnComboAttrAddNull ex
      *  requests a handback which contains the associated service/attribute 
      *  "tuple" to be associated with the event.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -161,7 +162,7 @@ public class NotifyOnComboAttrAddNull ex
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	    listener = new Listener();
         /* load each of the attribute classes and create a non-initialized
@@ -242,6 +243,7 @@ public class NotifyOnComboAttrAddNull ex
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNonNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNonNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNonNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNonNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -140,7 +141,7 @@ public class NotifyOnComboAttrDelNonNull
      *  requests a handback which contains the associated service/attribute 
      *  "tuple" to be associated with the event.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -165,7 +166,7 @@ public class NotifyOnComboAttrDelNonNull
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* load and create an initialized instance (non-null fields) of each
@@ -261,6 +262,7 @@ public class NotifyOnComboAttrDelNonNull
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrDelNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -140,7 +141,7 @@ public class NotifyOnComboAttrDelNull ex
      *  requests a handback which contains the associated service/attribute 
      *  "tuple" to be associated with the event.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -165,7 +166,7 @@ public class NotifyOnComboAttrDelNull ex
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* load each of the attribute classes and create a non-initialized
@@ -261,6 +262,7 @@ public class NotifyOnComboAttrDelNull ex
 
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNonNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNonNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNonNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNonNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -140,7 +141,7 @@ public class NotifyOnComboAttrModNonNull
      *  a handback which contains the corresponding service/attribute 
      *  "tuple" to be associated with the event. 
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -165,7 +166,7 @@ public class NotifyOnComboAttrModNonNull
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* load and create an initialized instance (non-null fields) of each
@@ -262,6 +263,7 @@ public class NotifyOnComboAttrModNonNull
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboAttrModNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -141,7 +142,7 @@ public class NotifyOnComboAttrModNull ex
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -166,7 +167,7 @@ public class NotifyOnComboAttrModNull ex
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* load each of the attribute classes and create a non-initialized
@@ -262,6 +263,7 @@ public class NotifyOnComboAttrModNull ex
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcLeaseExp.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcLeaseExp.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcLeaseExp.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcLeaseExp.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -140,7 +141,7 @@ public class NotifyOnComboSrvcLeaseExp e
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -167,7 +168,7 @@ public class NotifyOnComboSrvcLeaseExp e
                                      maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* retrieve the proxies to the lookup service */
@@ -247,6 +248,7 @@ public class NotifyOnComboSrvcLeaseExp e
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcReg.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcReg.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcReg.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnComboSrvcReg.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -139,7 +140,7 @@ public class NotifyOnComboSrvcReg extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -164,7 +165,7 @@ public class NotifyOnComboSrvcReg extend
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* retrieve the proxies to the lookup service */
@@ -251,6 +252,7 @@ public class NotifyOnComboSrvcReg extend
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNonNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNonNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReRegOldSrvcs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReRegOldSrvcs.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -61,9 +62,9 @@ public class ReRegOldSrvcs extends QATes
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
 	srvcRegs = super.registerAll();
@@ -76,6 +77,7 @@ public class ReRegOldSrvcs extends QATes
 	    tmpls[i] = new ServiceTemplate(srvcRegs[i].getServiceID(),
                                            null,null);
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByAttr.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByAttr.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByAttr.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByAttr.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -91,7 +92,7 @@ public class ReturnOnLookupByAttr extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int n;
         Entry[] attrs;
@@ -99,7 +100,7 @@ public class ReturnOnLookupByAttr extend
         /* change to n if you want to skip the first n attributes in the set */
         int attrStartIndx = 0; 
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
         attrs = super.createAttributes(ATTR_CLASSES);
         nAttrs = super.getNAttrInstances();
@@ -126,6 +127,7 @@ public class ReturnOnLookupByAttr extend
                 k++;
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByType.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByType.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByType.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByType.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -83,8 +84,8 @@ public class ReturnOnLookupByType extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         nClasses = super.getNTestClasses();
         nInstancesPerClass = super.getNInstancesPerClass();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
@@ -96,6 +97,7 @@ public class ReturnOnLookupByType extend
 	    Class[] classType = {c};
 	    tmpls[i] = new ServiceTemplate(null,classType,null);
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByTypeAttr.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByTypeAttr.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByTypeAttr.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReturnOnLookupByTypeAttr.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -92,7 +93,7 @@ public class ReturnOnLookupByTypeAttr ex
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int n;
         Entry[] attrs;
@@ -100,7 +101,7 @@ public class ReturnOnLookupByTypeAttr ex
         /* change to n if you want to skip the first n attributes in the set */
         int attrStartIndx = 0; 
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
         attrs = super.createAttributes(ATTR_CLASSES);
         nAttrs = super.getNAttrInstances();
@@ -131,6 +132,7 @@ public class ReturnOnLookupByTypeAttr ex
 		k++;
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredAddAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredAddAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredAddAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredAddAttributes.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -54,14 +55,15 @@ public class ExpiredAddAttributes extend
     private long leaseStartTime; 
     private Entry[] attrEntries;
     
-    public void setup(QAConfig sysConfig) throws Exception
+    public Test construct(QAConfig sysConfig) throws Exception
     {
- 	super.setup(sysConfig);
+ 	super.construct(sysConfig);
 	attrEntries = super.createAttributes(ATTR_CLASSES);
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
  	srvcRegs = registerAll(leaseDuration);
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
     }
 
     /** Executes the current QA test. */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseCancel.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseCancel.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredModifyAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredModifyAttributes.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ import com.sun.jini.qa.harness.QAConfig;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
+import com.sun.jini.qa.harness.Test;
 
 import java.rmi.RemoteException;
 import java.io.IOException;
@@ -54,8 +55,8 @@ public class ExpiredModifyAttributes ext
     private Entry[] modAttrs;
     private int attrsLen;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	attrEntries = super.createAttributes(ATTR_CLASSES);
 	modAttrs = new Entry[attrEntries.length];
 	for(int i=0; i<modAttrs.length;i++) {
@@ -65,6 +66,7 @@ public class ExpiredModifyAttributes ext
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
  	srvcRegs = registerAll(leaseDuration);
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
     }
 
     /** Executes the current QA test. */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseCancel.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseCancel.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseCancel.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseCancel.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -52,8 +53,8 @@ public class ExpiredServiceLeaseCancel e
     private int nInstances = 0;
     private long leaseStartTime;  
     
-    public void setup(QAConfig sysConfig) throws Exception {
- 	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+ 	super.construct(sysConfig);
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
 	proxy = super.getProxy();
@@ -64,6 +65,7 @@ public class ExpiredServiceLeaseCancel e
 	    srvcLeases[i] = getRegistrationLease(srvcRegs[i]);
 	}
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
     }
 
     /** Executes the current QA test. */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseRenew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseRenew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseRenew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredServiceLeaseRenew.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -52,8 +53,8 @@ public class ExpiredServiceLeaseRenew ex
     private int nInstances = 0;
     private long leaseStartTime;  
     
-    public void setup(QAConfig sysConfig) throws Exception {
- 	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+ 	super.construct(sysConfig);
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
 	proxy = super.getProxy();
@@ -63,6 +64,7 @@ public class ExpiredServiceLeaseRenew ex
 	    srvcLeases[i] = getRegistrationLease(srvcRegs[i]);
 	}
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
     }
 
     /** Executes the current QA test. */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredSetAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredSetAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredSetAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredSetAttributes.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -54,13 +55,14 @@ public class ExpiredSetAttributes extend
     private long leaseStartTime; 
     private Entry[] attrEntries;
     
-    public void setup(QAConfig sysConfig) throws Exception {
- 	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+ 	super.construct(sysConfig);
 	attrEntries = super.createAttributes(ATTR_CLASSES);
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
  	srvcRegs = registerAll(leaseDuration);
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
    }
 
     /** Executes the current QA test. */
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySrvcID.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySrvcID.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -56,9 +57,9 @@ public class LookupBySrvcID extends QATe
      *  which each element contains the service ID of one of the registered
      *  service items.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
 	logger.log(Level.FINE, "in setup() method.");
 
@@ -73,17 +74,18 @@ public class LookupBySrvcID extends QATe
 	    srvcIDTmpls[i] = new ServiceTemplate(srvcRegs[i].getServiceID(),
                                                  null,null);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service registered:  
      *      1. Performs a simple lookup using the corresponding template 
      *         created during setup and then tests that the object returned 
      *         equals the service item that was registered with the 
      *         corresponding service ID.
      *      2. Performs a match lookup using the corresponding template 
      *         created during setup and then tests that the number of matches
      *         found equals 1; and that the object returned equals the 
      *         service item that was registered with the corresponding 
      *         service ID.
@@ -73,17 +74,18 @@ public class LookupBySrvcID extends QATe
      *  For each service registered:  
      *      1. Performs a simple lookup using the corresponding template 
-     *         created during setup and then tests that the object returned 
+     *         created during construct and then tests that the object returned 
      *         equals the service item that was registered with the 
      *         corresponding service ID.
@@ -73,17 +74,18 @@ public class LookupBySrvcID extends QATe
      *         corresponding service ID.
      *      2. Performs a match lookup using the corresponding template 
-     *         created during setup and then tests that the number of matches
+     *         created during construct and then tests that the number of matches
      *         found equals 1; and that the object returned equals the 
      *         service item that was registered with the corresponding 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySuper.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySuper.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySuper.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupBySuper.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -63,12 +64,12 @@ public class LookupBySuper extends QATes
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         boolean exit_loop;
         int indx;
 
-	super.setup(sysConfig); 
+	super.construct(sysConfig); 
 
 	logger.log(Level.FINE, "in setup() method.");
 
@@ -102,6 +103,7 @@ public class LookupBySuper extends QATes
 		}
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -109,7 +111,7 @@ public class LookupBySuper extends QATes
      *  For each registered service:  
      *     For each super class in the set of super classes:  
      *        Performs a match lookup using the corresponding template 
      *        created during setup and then tests that the number of matches
      *        found equals the number of matches expected; and that the set
      *        of objects returned equals the expected set of corresponding
      *        service items.
@@ -109,7 +111,7 @@ public class LookupBySuper extends QATes
      *     For each super class in the set of super classes:  
      *        Performs a match lookup using the corresponding template 
-     *        created during setup and then tests that the number of matches
+     *        created during construct and then tests that the number of matches
      *        found equals the number of matches expected; and that the set
      *        of objects returned equals the expected set of corresponding

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleEvntLeaseRenewals.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleEvntLeaseRenewals.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleEvntLeaseRenewals.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleEvntLeaseRenewals.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -106,10 +107,10 @@ public class MultipleEvntLeaseRenewals e
      *  contains one of the event leases created during the event 
      *  notification registration process.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 
         QATestUtils.setLeaseDuration(sysConfig, 1000L * 60 * 60);
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	listener = new Listener();
 	logger.log(Level.FINE, "in setup() method.");
         nInstances = super.getNInstances();
@@ -127,6 +128,7 @@ public class MultipleEvntLeaseRenewals e
 	notificationEvnt = new ServiceEvent[nInstances];
 	leaseStartTime = QATestUtils.getCurTime();
 	registerAllEvents();
+        return this;
     }
 
     /** Executes the current QA test.
@@ -236,7 +238,7 @@ public class MultipleEvntLeaseRenewals e
     
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
      * corresponding template created during setup and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 
      * event notification registration process.
@@ -236,7 +238,7 @@ public class MultipleEvntLeaseRenewals e
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
-     * corresponding template created during setup and corresponding to
+     * corresponding template created during construct and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleSrvcLeaseRenewals.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/MultipleSrvcLeaseRenewals.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrAdd.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrAdd.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -100,13 +101,13 @@ public class NotifyOnAttrAdd extends QAT
      *  appropriate transition mask; along with a handback containing the 
      *  service ID . 
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
         ServiceID curSrvcID;
 	EventRegistration[] evntRegs;
         int regTransitions =   ServiceRegistrar.TRANSITION_MATCH_MATCH
                              | ServiceRegistrar.TRANSITION_MATCH_NOMATCH;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
 	logger.log(Level.FINE, "NotifyOnAttrAdd : in setup() method.");
 
@@ -131,11 +132,12 @@ public class NotifyOnAttrAdd extends QAT
 			      Long.MAX_VALUE);
 	    evntRegs[i] = prepareEventRegistration(er);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service instance created during setup, chooses one of the
      *  attributes (random, round-robin, it doesn't matter) and adds 
      *  that attribute to the current service item. Waits a configured
      *  amount of time to allow for all of the events to be generated
@@ -131,11 +132,12 @@ public class NotifyOnAttrAdd extends QAT
     /** Executes the current QA test.
      *
-     *  For each service instance created during setup, chooses one of the
+     *  For each service instance created during construct, chooses one of the
      *  attributes (random, round-robin, it doesn't matter) and adds 
      *  that attribute to the current service item. Waits a configured

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrDel.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrDel.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrDel.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrDel.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -108,14 +109,14 @@ public class NotifyOnAttrDel extends QAT
      *  and the appropriate transition mask; along with a handback containing 
      *  the service ID . 
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 
         int i,j,k;
         ServiceID curSrvcID;
         EventRegistration[] evntRegs;
         int regTransitions =   ServiceRegistrar.TRANSITION_MATCH_MATCH
                              | ServiceRegistrar.TRANSITION_MATCH_NOMATCH;
-        super.setup(sysConfig);
+        super.construct(sysConfig);
 
 	logger.log(Level.FINE, "in setup() method.");
 
@@ -155,11 +156,12 @@ public class NotifyOnAttrDel extends QAT
 			      Long.MAX_VALUE);
 	    evntRegs[i] = prepareEventRegistration(er);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service instance created during setup, deletes the attribute
      *  belonging to that service by modifying the attribute with the
      *  the corresponding null attribute from the second set. Waits a 
      *  configured amount of time to allow for all of the events to be 
@@ -155,11 +156,12 @@ public class NotifyOnAttrDel extends QAT
     /** Executes the current QA test.
      *
-     *  For each service instance created during setup, deletes the attribute
+     *  For each service instance created during construct, deletes the attribute
      *  belonging to that service by modifying the attribute with the
      *  the corresponding null attribute from the second set. Waits a 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrMod.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrMod.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrMod.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnAttrMod.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.qa.harness.TestException;
 import java.util.logging.Level;
@@ -105,14 +106,14 @@ public class NotifyOnAttrMod extends QAT
      *  on the contents of the corresponding template and the appropriate 
      *  transition mask; along with a handback containing the service ID . 
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 
         int i,j,k;
         ServiceID curSrvcID;
 	EventRegistration[] evntRegs;
         int regTransitions =   ServiceRegistrar.TRANSITION_MATCH_MATCH
                              | ServiceRegistrar.TRANSITION_MATCH_NOMATCH;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
 	logger.log(Level.FINE, "in setup() method.");
 
@@ -155,13 +156,14 @@ public class NotifyOnAttrMod extends QAT
 			      Long.MAX_VALUE);
 	    evntRegs[i] = prepareEventRegistration(er);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service instance created during setup, modifies the attribute
      *  belonging to that service with the corresponding attribute from the
      *  second set of attributes created during setup. Waits a configured
      *  amount of time to allow for all of the events to be generated
      *  and collected. Determines if all of the expected -- as well as 
      *  no un-expected -- events have arrived. This test depends on the 
@@ -155,13 +156,14 @@ public class NotifyOnAttrMod extends QAT
     /** Executes the current QA test.
      *
-     *  For each service instance created during setup, modifies the attribute
+     *  For each service instance created during construct, modifies the attribute
      *  belonging to that service with the corresponding attribute from the
@@ -155,13 +156,14 @@ public class NotifyOnAttrMod extends QAT
      *  belonging to that service with the corresponding attribute from the
-     *  second set of attributes created during setup. Waits a configured
+     *  second set of attributes created during construct. Waits a configured
      *  amount of time to allow for all of the events to be generated
      *  and collected. Determines if all of the expected -- as well as 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnSrvcLeaseExpiration.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/NotifyOnSrvcLeaseExpiration.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/SrvcLeaseExpiration.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/SrvcLeaseExpiration.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.qa.harness.TestException;
 import java.util.logging.Level;
@@ -68,9 +69,9 @@ public class SrvcLeaseExpiration extends
      *  an approximate service lease start time for each service item by 
      *  retrieving the current system time.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
 	logger.log(Level.FINE, "in setup() method.");
 
@@ -86,6 +87,7 @@ public class SrvcLeaseExpiration extends
                                                  null,null);
 	}
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
     }
 
     /** Executes the current QA test.
@@ -126,7 +128,7 @@ public class SrvcLeaseExpiration extends
     }
  
     /* Perform both a simple and a match lookup using the ServiceTemplate
      * created during setup. Verifies that every simple lookup returns
      * a null object; and every match lookup returns zero matches.
      */
     private void doLookupNoMatch() throws TestException, RemoteException {
@@ -126,7 +128,7 @@ public class SrvcLeaseExpiration extends
  
     /* Perform both a simple and a match lookup using the ServiceTemplate
-     * created during setup. Verifies that every simple lookup returns
+     * created during construct. Verifies that every simple lookup returns
      * a null object; and every match lookup returns zero matches.
      */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/EmptyLookup.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/EmptyLookup.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/EmptyLookup.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/EmptyLookup.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -55,19 +56,20 @@ public class EmptyLookup extends QATestR
      *  with all entries null, that will be used in a lookup; and that will 
      *  return all items registered.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         /* add 1 to include the Registrar Service itself */
         expectedNMatches = 1+super.getNInstances();
 	ServiceItem[] srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
 	ServiceRegistration[] srvcRegs = super.registerAll();
 	proxy = super.getProxy();
 	tmpl = new ServiceTemplate(null,null,null);
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  Performs a match lookup using the template created during setup and 
      *  zero maximum matches. Verifies that the expected number of services
      *  are returned by the call to lookup().
      */
@@ -55,19 +56,20 @@ public class EmptyLookup extends QATestR
     /** Executes the current QA test.
      *
-     *  Performs a match lookup using the template created during setup and 
+     *  Performs a match lookup using the template created during construct and 
      *  zero maximum matches. Verifies that the expected number of services
      *  are returned by the call to lookup().

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -139,10 +140,10 @@ public class GetEntryClassesAttrNull ext
      *  of attributes. Adds each attribute instance from the first set of
      *  attributes to each registered service.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
         /* create the array of Entry arrays holding the attributes */
         Entry[][] srvcAttrs    = new Entry[nAttrClasses][1];
@@ -189,11 +190,12 @@ public class GetEntryClassesAttrNull ext
 		srvcRegs[i].addAttributes(srvcAttrs[j]);
 	    }
         }
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  Using the ServiceTemplate created during setup, invokes the method
      *  getEntryClasses(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.
      */
@@ -189,11 +190,12 @@ public class GetEntryClassesAttrNull ext
     /** Executes the current QA test.
      *
-     *  Using the ServiceTemplate created during setup, invokes the method
+     *  Using the ServiceTemplate created during construct, invokes the method
      *  getEntryClasses(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrVals.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrVals.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrVals.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesAttrVals.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -147,10 +148,10 @@ public class GetEntryClassesAttrVals ext
      *  of attributes. Adds each attribute instance from the first set of
      *  attributes to each registered service.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
         /* create the array of Entry arrays holding the attributes */
         Entry[][] srvcAttrs    = new Entry[nAttrClasses][1];
@@ -230,11 +231,12 @@ public class GetEntryClassesAttrVals ext
 		srvcRegs[i].addAttributes(srvcAttrs[j]);
 	    }
         }
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  Using the ServiceTemplate created during setup, invokes the method
      *  getEntryClasses(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.
      */
@@ -230,11 +231,12 @@ public class GetEntryClassesAttrVals ext
     /** Executes the current QA test.
      *
-     *  Using the ServiceTemplate created during setup, invokes the method
+     *  Using the ServiceTemplate created during construct, invokes the method
      *  getEntryClasses(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesEmpty.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -107,10 +108,10 @@ public class GetEntryClassesEmpty extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
         /* create the array of Entry arrays holding the attributes */
         attrEntries = super.createAttributes(ATTR_CLASSES);
@@ -145,11 +146,12 @@ public class GetEntryClassesEmpty extend
                     srvcRegs[i].addAttributes(attrs[j]);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  Using the empty ServiceTemplate created during setup, invokes the
      *  method getServiceTypes(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.
      */
@@ -145,11 +146,12 @@ public class GetEntryClassesEmpty extend
     /** Executes the current QA test.
      *
-     *  Using the empty ServiceTemplate created during setup, invokes the
+     *  Using the empty ServiceTemplate created during construct, invokes the
      *  method getServiceTypes(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesTypeAttr.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesTypeAttr.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesTypeAttr.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetEntryClassesTypeAttr.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -142,10 +143,10 @@ public class GetEntryClassesTypeAttr ext
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
         /* create the array of Entry arrays holding the attributes */
         Entry[][] srvcAttrs    = new Entry[nAttrClasses][1];
@@ -197,11 +198,12 @@ public class GetEntryClassesTypeAttr ext
 		srvcRegs[i].addAttributes(srvcAttrs[j]);
 	    }
         }
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  Using the ServiceTemplate created during setup, invokes the method
      *  getEntryClasses(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.
      *  @exception QATestException usually indicates test failure
@@ -197,11 +198,12 @@ public class GetEntryClassesTypeAttr ext
     /** Executes the current QA test.
      *
-     *  Using the ServiceTemplate created during setup, invokes the method
+     *  Using the ServiceTemplate created during construct, invokes the method
      *  getEntryClasses(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttr.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttr.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttr.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttr.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -113,9 +114,9 @@ public class GetFieldValuesAttr extends 
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* retrieve the proxies to the lookup service */
 	proxy = super.getProxy();
         /* load each of the attribute classes and create an initialized
@@ -130,6 +131,7 @@ public class GetFieldValuesAttr extends 
          */
         srvcItem = super.createServiceItem(TEST_SRVC_CLASSES[0],0,attrEntries);
         srvcReg  = registerItem(srvcItem,Long.MAX_VALUE, proxy);
+        return this;
     }
 
     /** Performs actions necessary to prepare for execution of the 
@@ -138,7 +140,7 @@ public class GetFieldValuesAttr extends 
      *  For each attribute belonging to the service registered with lookup and
      *     for each field value of the attribute:
      *       1. Calls the method getFieldValues() inputting the template
      *          created during setup.
      *       2. Verifies that getFieldValues() returns the expected results.
      *  @exception QATestException usually indicates test failure
      */
@@ -138,7 +140,7 @@ public class GetFieldValuesAttr extends 
      *     for each field value of the attribute:
      *       1. Calls the method getFieldValues() inputting the template
-     *          created during setup.
+     *          created during construct.
      *       2. Verifies that getFieldValues() returns the expected results.
      *  @exception QATestException usually indicates test failure

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttrNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttrNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttrNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetFieldValuesAttrNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -112,9 +113,9 @@ public class GetFieldValuesAttrNull exte
      *  and creates an instance of it containing all of the initialized 
      *  attributes; registers that service class with the lookup service.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* retrieve the proxies to the lookup service */
 	proxy = super.getProxy();
         /* load each of the attribute classes and create a non-initialized
@@ -131,6 +132,7 @@ public class GetFieldValuesAttrNull exte
         attrEntries = super.createNonNullFieldAttributes();
         srvcItem = super.createServiceItem(TEST_SRVC_CLASSES[0],0,attrEntries);
         srvcReg  = registerItem(srvcItem,Long.MAX_VALUE, proxy);
+        return this;
     }
 
     /** Executes the current QA test.
@@ -138,7 +140,7 @@ public class GetFieldValuesAttrNull exte
      *  For each attribute belonging to the service registered with lookup and
      *     for each field value of the attribute:
      *       1. Calls the method getFieldValues() inputting the template
      *          created during setup.
      *       2. Verifies that getFieldValues() returns the expected results.
      */
     public void run() throws Exception {
@@ -138,7 +140,7 @@ public class GetFieldValuesAttrNull exte
      *     for each field value of the attribute:
      *       1. Calls the method getFieldValues() inputting the template
-     *          created during setup.
+     *          created during construct.
      *       2. Verifies that getFieldValues() returns the expected results.
      */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesAttr.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesAttr.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesAttr.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesAttr.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -90,10 +91,10 @@ public class GetServiceTypesAttr extends
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
 
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 
         /* create the array of Entry arrays holding the attributes */
         attrEntries = super.createAttributes(ATTR_CLASSES);
@@ -121,11 +122,12 @@ public class GetServiceTypesAttr extends
 		srvcRegs[i].addAttributes(attrs[j]);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each attribute object instantiated during setup, uses the
      *  corresponding ServiceTemplate to invoke the method getServiceTypes().
      *  Verifies that the set of class types returned matches the expected set
      *  of type descriptors.
@@ -121,11 +122,12 @@ public class GetServiceTypesAttr extends
     /** Executes the current QA test.
      *
-     *  For each attribute object instantiated during setup, uses the
+     *  For each attribute object instantiated during construct, uses the
      *  corresponding ServiceTemplate to invoke the method getServiceTypes().
      *  Verifies that the set of class types returned matches the expected set

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesClass.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesClass.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesClass.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesClass.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -91,8 +92,8 @@ public class GetServiceTypesClass extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         nClasses = super.getNTestClasses();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
 	srvcRegs = super.registerAll();
@@ -104,12 +105,13 @@ public class GetServiceTypesClass extend
 	    Class[] classType = {c};
 	    classTmpls[i] = new ServiceTemplate(null,classType,null);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each class type of the test services created and registered
      *  during setup, uses the corresponding ServiceTemplate to invoke the
      *  method getServiceTypes(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.
      */
@@ -104,12 +105,13 @@ public class GetServiceTypesClass extend
      *
      *  For each class type of the test services created and registered
-     *  during setup, uses the corresponding ServiceTemplate to invoke the
+     *  during construct, uses the corresponding ServiceTemplate to invoke the
      *  method getServiceTypes(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/GetServiceTypesEmpty.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -86,17 +87,18 @@ public class GetServiceTypesEmpty extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
 	srvcRegs = super.registerAll();
 	proxy = super.getProxy();
 	emptyTmpl = new ServiceTemplate(null,null,null);
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  Using the empty ServiceTemplate created during setup, invokes the
      *  method getServiceTypes(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.
      *  @exception QATestException usually indicates test failure
@@ -86,17 +87,18 @@ public class GetServiceTypesEmpty extend
     /** Executes the current QA test.
      *
-     *  Using the empty ServiceTemplate created during setup, invokes the
+     *  Using the empty ServiceTemplate created during construct, invokes the
      *  method getServiceTypes(). Verifies that the set of class types returned
      *  matches the expected set of type descriptors.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentNewSrvcReg.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/IdempotentNewSrvcReg.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNonNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNonNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -135,7 +136,7 @@ public class NotifyOnEntryAttrAddNonNull
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -160,7 +161,7 @@ public class NotifyOnEntryAttrAddNonNull
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* retrieve the proxies to the lookup service */
@@ -218,12 +219,13 @@ public class NotifyOnEntryAttrAddNonNull
                 k++;
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service instance created during setup and
      *     for each attribute instance created during setup:
      *       1. Retrieves the expected event information corresponding to
      *          the current service and attribute instance; populates
      *          the "accumulation" vector with that information.
@@ -218,12 +219,13 @@ public class NotifyOnEntryAttrAddNonNull
     /** Executes the current QA test.
      *
-     *  For each service instance created during setup and
-     *     for each attribute instance created during setup:
+     *  For each service instance created during construct and
+     *     for each attribute instance created during construct:
      *       1. Retrieves the expected event information corresponding to
      *          the current service and attribute instance; populates

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntryAttrAddNull.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -134,7 +135,7 @@ public class NotifyOnEntryAttrAddNull ex
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -159,7 +160,7 @@ public class NotifyOnEntryAttrAddNull ex
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* retrieve the proxies to the lookup service */
@@ -217,12 +218,13 @@ public class NotifyOnEntryAttrAddNull ex
                 k++;
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service instance created during setup and
      *     for each attribute instance created during setup:
      *       1. Retrieves the expected event information corresponding to
      *          the current service and attribute instance; populates
      *          the "accumulation" vector with that information.
@@ -217,12 +218,13 @@ public class NotifyOnEntryAttrAddNull ex
     /** Executes the current QA test.
      *
-     *  For each service instance created during setup and
-     *     for each attribute instance created during setup:
+     *  For each service instance created during construct and
+     *     for each attribute instance created during construct:
      *       1. Retrieves the expected event information corresponding to
      *          the current service and attribute instance; populates

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntrySrvcReg.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntrySrvcReg.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntrySrvcReg.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/NotifyOnEntrySrvcReg.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set01;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -132,7 +133,7 @@ public class NotifyOnEntrySrvcReg extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k,n;
         int transitionMask =   ServiceRegistrar.TRANSITION_NOMATCH_MATCH;
 
@@ -155,7 +156,7 @@ public class NotifyOnEntrySrvcReg extend
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* retrieve the proxies to the lookup service */
@@ -215,12 +216,13 @@ public class NotifyOnEntrySrvcReg extend
                 k++;
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service instance created during setup and
      *     for each attribute instance created during setup:
      *       1. Retrieves the expected event information corresponding to
      *          the current service and attribute instance; populates
      *          the "accumulation" vector with that information.
@@ -215,12 +216,13 @@ public class NotifyOnEntrySrvcReg extend
     /** Executes the current QA test.
      *
-     *  For each service instance created during setup and
-     *     for each attribute instance created during setup:
+     *  For each service instance created during construct and
+     *     for each attribute instance created during construct:
      *       1. Retrieves the expected event information corresponding to
      *          the current service and attribute instance; populates

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReRegOldSrvcs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set01/ReRegOldSrvcs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseCancel.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseCancel.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -88,9 +89,9 @@ public class ExpiredEventLeaseCancel ext
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	listener = new Listener();
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
@@ -110,6 +111,7 @@ public class ExpiredEventLeaseCancel ext
 	evntLeases = new Lease[nInstances];
 	registerAllEvents();
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
    }
 
     public void run() throws Exception {
@@ -119,7 +121,7 @@ public class ExpiredEventLeaseCancel ext
 
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
      * corresponding template created during setup and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 
      * event notification registration process.
@@ -119,7 +121,7 @@ public class ExpiredEventLeaseCancel ext
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
-     * corresponding template created during setup and corresponding to
+     * corresponding template created during construct and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseRenew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseRenew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseRenew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredEventLeaseRenew.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -88,9 +89,9 @@ public class ExpiredEventLeaseRenew exte
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	listener = new Listener();
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
@@ -110,6 +111,7 @@ public class ExpiredEventLeaseRenew exte
 	evntLeases = new Lease[nInstances];
 	registerAllEvents();
 	leaseStartTime = QATestUtils.getCurTime();
+        return this;
    }
 
     public void run() throws Exception {
@@ -119,7 +121,7 @@ public class ExpiredEventLeaseRenew exte
 
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
      * corresponding template created during setup and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 
      * event notification registration process.
@@ -119,7 +121,7 @@ public class ExpiredEventLeaseRenew exte
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
-     * corresponding template created during setup and corresponding to
+     * corresponding template created during construct and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapCancel.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapCancel.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapCancel.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapCancel.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -91,9 +92,9 @@ public class ExpiredLeaseMapCancel exten
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	listener = new Listener();
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
@@ -114,6 +115,7 @@ public class ExpiredLeaseMapCancel exten
 	registerAllEvents();
 	leaseStartTime = QATestUtils.getCurTime();
 	createLeaseMap();
+        return this;
    }
 
     public void run() throws Exception {
@@ -139,7 +141,7 @@ public class ExpiredLeaseMapCancel exten
 
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
      * corresponding template created during setup and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 
      * event notification registration process.
@@ -139,7 +141,7 @@ public class ExpiredLeaseMapCancel exten
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
-     * corresponding template created during setup and corresponding to
+     * corresponding template created during construct and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapRenew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapRenew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapRenew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredLeaseMapRenew.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -91,9 +92,9 @@ public class ExpiredLeaseMapRenew extend
      *  @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	listener = new Listener();
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
@@ -114,6 +115,7 @@ public class ExpiredLeaseMapRenew extend
 	registerAllEvents();
 	leaseStartTime = QATestUtils.getCurTime();
 	createLeaseMap();
+        return this;
    }
 
     public void run() throws Exception {
@@ -139,7 +141,7 @@ public class ExpiredLeaseMapRenew extend
 
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
      * corresponding template created during setup and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 
      * event notification registration process.
@@ -139,7 +141,7 @@ public class ExpiredLeaseMapRenew extend
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
-     * corresponding template created during setup and corresponding to
+     * corresponding template created during construct and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredModifyAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ExpiredModifyAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================